@@ -5,7 +5,8 @@ rm -rf ./ips.txt
 fi
 while [ -z "$RESPONSE" ];
 do
-echo "Please enter an IP Address in the format XXX.XXX.XXX./c"
+clear
+echo "Please enter an IP Address in the format XXX.XXX.XXX."
 echo "The program will create a file called ips.txt which will"
 echo "include a C-Class subnet of IPs.  ex 114.23.11."
 read RESPONSE
@@ -14,6 +15,6 @@ x=1
 while [ $x -le 255 ] 
 do
 echo "$RESPONSE$x" >> ./ips.txt
-x=`echo "$x + 1" | bc`
+x=`expr $x + 1`
 done
 echo "File sucessfully written."
\ No newline at end of file
